/// Josh's User Interface Library
/// A C++20 Library for creating, styling, and rendering of a UI/UX widgets.
/// Developed and Maintained by Josh O'Leary @ Redacted Software.
/// Special Thanks to William Tomasine II and Maxine Hayes.
/// (c) 2024 Redacted Software
/// This work is dedicated to the public domain.

/// @file FileDialog.hpp
/// @desc A dialog window that shows a selection of files on disk, and a form for naming, used for file loading and saving.
/// @edit 2024-5-29

#pragma once

#include <JUI/Widgets/Window.hpp>
#include <JUI/Widgets/UtilityBar.hpp>
#include <JUI/Widgets/ScrollingRect.hpp>

namespace JUI
{

	class FileListing : public JUI::Widget { };

	class FileDialogWindow : public JUI::Window
	{
	public:
   		Event<> UserCompleted;
        Event<> UserConfirmed;
        Event<> UserCancelled;
        FileDialogWindow() : Window() {
      		auto* toolbar = new JUI::UtilityBar(this->Content());

           	auto* file_listing = new JUI::ScrollingRect(this->Content());
            file_listing->Size({100_percent, 100_percent-20_px});

        }
        FileDialogWindow(const std::filesystem::path& root) : FileDialogWindow() {}
        explicit FileDialogWindow(Widget* parent, const std::filesystem::path& root) : FileDialogWindow(root)
        {
			Parent(parent);
        }


    protected:
    private:
	};


    class OpenFileDialogWindow : public JUI::Window { };
    class SaveFileDialogWindow : public JUI::Window { };
    class SelectFolderDialog : public JUI::Window { };

}